<?php
/**
 * Siteorigin Panels Compatibility File
 *
 * @package    ReviewPro
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Registers custom builder.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/register_widget
 */
function reviewpro_builders_init() {

	// Classic block
	require trailingslashit( get_template_directory() ) . 'inc/builder/classic.php';
	register_widget( 'ReviewPro_Classic_Block' );

	// Modern block
	require trailingslashit( get_template_directory() ) . 'inc/builder/modern.php';
	register_widget( 'ReviewPro_Modern_Block' );

	// Modern vertical block
	require trailingslashit( get_template_directory() ) . 'inc/builder/modern-vertical.php';
	register_widget( 'ReviewPro_Modern_Vertical_Block' );

	// Modern horizontal block
	require trailingslashit( get_template_directory() ) . 'inc/builder/modern-horizontal.php';
	register_widget( 'ReviewPro_Modern_Horizontal_Block' );

	// Grid block
	require trailingslashit( get_template_directory() ) . 'inc/builder/grid.php';
	register_widget( 'ReviewPro_Grid_Block' );

	// Grid classic block
	require trailingslashit( get_template_directory() ) . 'inc/builder/grid-classic.php';
	register_widget( 'ReviewPro_Grid_Classic_Block' );

	// Advertisement block
	require trailingslashit( get_template_directory() ) . 'inc/builder/ads.php';
	register_widget( 'ReviewPro_Ads_Block' );

	// Carousel Posts block
	require trailingslashit( get_template_directory() ) . 'inc/builder/carousel.php';
	register_widget( 'ReviewPro_Carousel_Block' );

}
add_action( 'widgets_init', 'reviewpro_builders_init' );

/**
 * Add new panel
 *
 * @since 1.0.0
 */
function reviewpro_panels_add_widgets_dialog_tabs( $tabs ){

	$tabs[] = array(
		'title'  => esc_html__( 'ReviewPro Widgets', 'reviewpro' ),
		'filter' => array(
			'installed' => true,
			'groups'    => array( 'reviewpro' )
		)
	);

	return $tabs;
}
add_filter( 'siteorigin_panels_widget_dialog_tabs', 'reviewpro_panels_add_widgets_dialog_tabs' );

/**
 * Set the groups for all ReviewPro Widgets
 *
 * @since 1.0.0
 */
function reviewpro_panels_add_widget_groups( $widgets ){
	$widgets['ReviewPro_Ads_Block']['groups'] = array( 'reviewpro' );
	$widgets['ReviewPro_Classic_Block']['groups'] = array( 'reviewpro' );
	$widgets['ReviewPro_Modern_Block']['groups'] = array( 'reviewpro' );
	$widgets['ReviewPro_Modern_Vertical_Block']['groups'] = array( 'reviewpro' );
	$widgets['ReviewPro_Modern_Horizontal_Block']['groups'] = array( 'reviewpro' );
	$widgets['ReviewPro_Grid_Block']['groups'] = array( 'reviewpro' );
	$widgets['ReviewPro_Grid_Classic_Block']['groups'] = array( 'reviewpro' );
	$widgets['ReviewPro_Carousel_Block']['groups'] = array( 'reviewpro' );
	return $widgets;
}
add_filter( 'siteorigin_panels_widgets', 'reviewpro_panels_add_widget_groups' );

/**
 * Change the margin bottom between block.
 *
 * @since 1.0.0
 */
function reviewpro_panels_margin_bottom( $panels_margin_bottom ) {
	$panels_margin_bottom = '50px';
	return $panels_margin_bottom;
}
add_filter( 'siteorigin_panels_css_row_margin_bottom', 'reviewpro_panels_margin_bottom', 10, 4 );

/**
 * Filter the widget output
 *
 * @since 1.0.0
 */
function reviewpro_panels_widget_args( $args ) {
	$args['before_title'] = '<h3 class="widget-title">';
	$args['after_title']  = '</h3>';
	return $args;
}
add_filter( 'siteorigin_panels_widget_args', 'reviewpro_panels_widget_args' );

/**
 * Adds default page layouts
 *
 * @since 1.0.0
 */
function reviewpro_prebuilt_page_layouts( $layouts ) {

	$layouts['modern-home'] = array (
		'name'        => esc_html__( 'Modern Home', 'reviewpro' ),
		'description' => esc_html__( 'Modern layout for home page.', 'reviewpro' ),
		'screenshot'  => get_template_directory_uri() . '/screenshot.png',
		'widgets' =>
		array(
			0 =>
			array(
				'id'    => '',
				'info'  => array(
					'class' => 'ReviewPro_Modern_Horizontal_Block',
					'id'    => '1',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
			1 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Block',
					'id'    => '2',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
			2 =>
			array(
				'text' => esc_html__( 'Display grid classic style posts list.', 'reviewpro' ),
				'info'  => array(
					'class' => 'ReviewPro_Grid_Classic_Block',
					'id'    => '3',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
			3 =>
			array(
				'title' => '',
				'text'  => esc_html__( 'Display your social media icons.', 'reviewpro' ),
				'info'  => array(
					'class' => 'ReviewPro_Social_Widget',
					'id'    => '4',
					'grid'  => '0',
					'cell'  => '1',
				),
			),
			4 =>
			array(
				'title'       => esc_html__( 'Get Updates', 'reviewpro' ),
				'text'        => esc_html__( 'FeedBurner email subscription.', 'reviewpro' ),
				'feed_id'     => 'ThemeJunkie',
				'before'      => esc_html__( 'Subscribe to our newsletter to receive breaking news by email.', 'reviewpro' ),
				'button_text' => esc_html__( 'Signup', 'reviewpro' ),
				'info'  => array(
					'class' => 'ReviewPro_Feedburner_Widget',
					'id'    => '5',
					'grid'  => '0',
					'cell'  => '1',
				),
			),
			5 =>
			array(
				'title'     => esc_html__( 'Popular Posts', 'reviewpro' ),
				'text'      => esc_html__( 'Display popular posts by comments with thumbnails.', 'reviewpro' ),
				'show_date' => true,
				'style'     => 'big-thumbnail-overlay',
				'info'  => array(
					'class' => 'ReviewPro_Popular_Widget',
					'id'    => '6',
					'grid'  => '0',
					'cell'  => '1',
				),
			),
			6 =>
			array(
				'text' => esc_html__( 'Display carousel style posts list.', 'reviewpro' ),
				'column' => 'four-columns',
				'info'  => array(
					'class' => 'ReviewPro_Carousel_Block',
					'id'    => '7',
					'grid'  => '1',
					'cell'  => '0',
				),
			),
			7 =>
			array(
				'text' => esc_html__( 'Display your ads using this block.', 'reviewpro' ),
				'info'  => array(
					'class' => 'ReviewPro_Ads_Block',
					'id'    => '8',
					'grid'  => '1',
					'cell'  => '0',
				),
			),
			8 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Vertical_Block',
					'id'    => '9',
					'grid'  => '2',
					'cell'  => '0',
				),
			),
			9 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Vertical_Block',
					'id'    => '10',
					'grid'  => '2',
					'cell'  => '1',
				),
			),
			10 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Vertical_Block',
					'id'    => '11',
					'grid'  => '2',
					'cell'  => '2',
				),
			),
			11 =>
			array(
				'text' => esc_html__( 'Display your ads using this block.', 'reviewpro' ),
				'info'  => array(
					'class' => 'ReviewPro_Ads_Block',
					'id'    => '12',
					'grid'  => '3',
					'cell'  => '0',
				),
			),
			12 =>
			array(
				'text' => esc_html__( 'Display grid style posts list.', 'reviewpro' ),
				'number' => 6,
				'column' => 'three-columns',
				'info'  => array(
					'class' => 'ReviewPro_Grid_Block',
					'id'    => '13',
					'grid'  => '3',
					'cell'  => '0',
				),
			),
			13 =>
			array(
				'text' => esc_html__( 'Display classic style posts list.', 'reviewpro' ),
				'info'  => array(
					'class' => 'ReviewPro_Classic_Block',
					'id'    => '14',
					'grid'  => '4',
					'cell'  => '0',
				),
			),
			14 =>
			array(
				'text' => esc_html__( 'Display your ads using this block.', 'reviewpro' ),
				'info'  => array(
					'class' => 'ReviewPro_Ads_Widget',
					'id'    => '15',
					'grid'  => '4',
					'cell'  => '1',
				),
			),
			15 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Tabs_Widget',
					'id'    => '16',
					'grid'  => '4',
					'cell'  => '1',
				),
			),
			16 =>
			array(
				'text' => esc_html__( 'Display a Facebook Like Box to connect visitors to your Facebook Page.', 'reviewpro' ),
				'info'  => array(
					'class' => 'ReviewPro_Facebook_Widget',
					'id'    => '17',
					'grid'  => '4',
					'cell'  => '1',
				),
			),
		),

		'grids' =>
		array(
			0 =>
			array(
				'cells' => '2',
				'style' => '',
			),
			1 =>
			array(
				'cells' => '1',
				'style' => '',
			),
			2 =>
			array(
				'cells' => '3',
				'style' => '',
			),
			3 =>
			array(
				'cells' => '1',
				'style' => '',
			),
			4 =>
			array(
				'cells' => '2',
				'style' => '',
			),
		),

		'grid_cells' =>
		array(
			0 =>
			array(
				'weight' => '0.66',
				'grid'   => '0',
			),
			1 =>
			array(
				'weight' => '0.33',
				'grid'   => '0',
			),
			2 =>
			array(
				'weight' => '1',
				'grid'   => '1',
			),
			3 =>
			array(
				'weight' => '0.33',
				'grid'   => '2',
			),
			4 =>
			array(
				'weight' => '0.33',
				'grid'   => '2',
			),
			5 =>
			array(
				'weight' => '0.33',
				'grid'   => '2',
			),
			6 =>
			array(
				'weight' => '1',
				'grid'   => '3',
			),
			7 =>
			array(
				'weight' => '0.66',
				'grid'   => '4',
			),
			8 =>
			array(
				'weight' => '0.33',
				'grid'   => '4',
			),
		),
	);

	$layouts['classic-home'] = array (
		'name'        => esc_html__( 'Classic Home', 'reviewpro' ),
		'description' => esc_html__( 'Classic layout for home page.', 'reviewpro' ),
		'screenshot'  => get_template_directory_uri() . '/screenshot.png',
		'widgets' =>
		array(
			0 =>
			array(
				'id'    => '',
				'info'  => array(
					'class' => 'ReviewPro_Modern_Block',
					'id'    => '1',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
			1 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Ads_Block',
					'id'    => '2',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
			2 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Vertical_Block',
					'id'    => '3',
					'grid'  => '1',
					'cell'  => '0',
				),
			),
			3 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Vertical_Block',
					'id'    => '4',
					'grid'  => '1',
					'cell'  => '1',
				),
			),
			4 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Grid_Block',
					'id'    => '5',
					'grid'  => '2',
					'cell'  => '0',
				),
			),
			5 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Ads_Block',
					'id'    => '6',
					'grid'  => '2',
					'cell'  => '0',
				),
			),
			6 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Grid_Classic_Block',
					'id'    => '7',
					'grid'  => '2',
					'cell'  => '0',
				),
			),
			7 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Classic_Block',
					'id'    => '8',
					'grid'  => '2',
					'cell'  => '0',
				),
			),
		),

		'grids' =>
		array(
			0 =>
			array(
				'cells' => '1',
				'style' => '',
			),
			1 =>
			array(
				'cells' => '2',
				'style' => '',
			),
			2 =>
			array(
				'cells' => '1',
				'style' => '',
			),
		),

		'grid_cells' =>
		array(
			0 =>
			array(
				'weight' => '1',
				'grid'   => '0',
			),
			1 =>
			array(
				'weight' => '0.5',
				'grid'   => '1',
			),
			2 =>
			array(
				'weight' => '0.5',
				'grid'   => '1',
			),
			3 =>
			array(
				'weight' => '1',
				'grid'   => '2',
			),
		),
	);

	$layouts['simple-magazine'] = array (
		'name'        => esc_html__( 'Simple Magazine', 'reviewpro' ),
		'description' => esc_html__( 'Simple Magazine layout for home page.', 'reviewpro' ),
		'screenshot'  => get_template_directory_uri() . '/screenshot.png',
		'widgets' =>
		array(
			0 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Vertical_Block',
					'id'    => '1',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
			1 =>
			array(
				'title' => esc_html__( 'Video Of The Day' , 'reviewpro' ),
				'info'  => array(
					'class' => 'ReviewPro_Video_Widget',
					'id'    => '2',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
			2 =>
			array(
				'text' => esc_html__( 'Display grid classic style posts list.', 'reviewpro' ),
				'column' => 'two-columns',
				'number' => 4,
				'info'  => array(
					'class' => 'ReviewPro_Grid_Classic_Block',
					'id'    => '3',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
			3 =>
			array(
				'title'     => esc_html__( 'Popular Posts', 'reviewpro' ),
				'text'      => esc_html__( 'Display popular posts by comments with thumbnails.', 'reviewpro' ),
				'show_date' => true,
				'style'     => 'big-thumbnail',
				'limit'     => 5,
				'info'  => array(
					'class' => 'ReviewPro_Popular_Widget',
					'id'    => '4',
					'grid'  => '0',
					'cell'  => '1',
				),
			),
			4 =>
			array(
				'title'     => esc_html__( 'Most Views Posts', 'reviewpro' ),
				'text'      => esc_html__( 'Display the most views posts with thumbnails.', 'reviewpro' ),
				'show_date' => true,
				'show_view' => true,
				'style'     => 'big-thumbnail',
				'limit'     => 5,
				'info'  => array(
					'class' => 'ReviewPro_Views_Widget',
					'id'    => '5',
					'grid'  => '0',
					'cell'  => '1',
				),
			),
			5 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Block',
					'id'    => '6',
					'grid'  => '1',
					'cell'  => '0',
				),
			),
			6 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Ads_Block',
					'id'    => '7',
					'grid'  => '1',
					'cell'  => '0',
				),
			),
			7 =>
			array(
				'text' => esc_html__( 'Display classic style posts list.', 'reviewpro' ),
				'info'  => array(
					'class' => 'ReviewPro_Classic_Block',
					'id'    => '8',
					'grid'  => '1',
					'cell'  => '0',
				),
			),
		),

		'grids' =>
		array(
			0 =>
			array(
				'cells' => '2',
				'style' => '',
			),
			1 =>
			array(
				'cells' => '1',
				'style' => '',
			),
		),

		'grid_cells' =>
		array(
			0 =>
			array(
				'weight' => '0.66',
				'grid'   => '0',
			),
			1 =>
			array(
				'weight' => '0.33',
				'grid'   => '0',
			),
			2 =>
			array(
				'weight' => '1',
				'grid'   => '1',
			),
		),
	);

	$layouts['simple-magazine-left'] = array (
		'name'        => esc_html__( 'Simple Left Sidebar', 'reviewpro' ),
		'description' => esc_html__( 'Simple Magazine Left Sidebar layout for home page.', 'reviewpro' ),
		'screenshot'  => get_template_directory_uri() . '/screenshot.png',
		'widgets' =>
		array(
			0 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Vertical_Block',
					'id'    => '1',
					'grid'  => '0',
					'cell'  => '1',
				),
			),
			1 =>
			array(
				'title' => esc_html__( 'Video Of The Day' , 'reviewpro' ),
				'info'  => array(
					'class' => 'ReviewPro_Video_Widget',
					'id'    => '2',
					'grid'  => '0',
					'cell'  => '1',
				),
			),
			2 =>
			array(
				'text' => esc_html__( 'Display grid classic style posts list.', 'reviewpro' ),
				'column' => 'two-columns',
				'number' => 4,
				'info'  => array(
					'class' => 'ReviewPro_Grid_Classic_Block',
					'id'    => '3',
					'grid'  => '0',
					'cell'  => '1',
				),
			),
			3 =>
			array(
				'title'     => esc_html__( 'Popular Posts', 'reviewpro' ),
				'text'      => esc_html__( 'Display popular posts by comments with thumbnails.', 'reviewpro' ),
				'show_date' => true,
				'style'     => 'big-thumbnail',
				'limit'     => 5,
				'info'  => array(
					'class' => 'ReviewPro_Popular_Widget',
					'id'    => '4',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
			4 =>
			array(
				'title'     => esc_html__( 'Most Views Posts', 'reviewpro' ),
				'text'      => esc_html__( 'Display the most views posts with thumbnails.', 'reviewpro' ),
				'show_date' => true,
				'show_view' => true,
				'style'     => 'big-thumbnail',
				'limit'     => 5,
				'info'  => array(
					'class' => 'ReviewPro_Views_Widget',
					'id'    => '5',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
			5 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Block',
					'id'    => '6',
					'grid'  => '1',
					'cell'  => '0',
				),
			),
			6 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Ads_Block',
					'id'    => '7',
					'grid'  => '1',
					'cell'  => '0',
				),
			),
			7 =>
			array(
				'text' => esc_html__( 'Display classic style posts list.', 'reviewpro' ),
				'info'  => array(
					'class' => 'ReviewPro_Classic_Block',
					'id'    => '8',
					'grid'  => '1',
					'cell'  => '0',
				),
			),
		),

		'grids' =>
		array(
			0 =>
			array(
				'cells' => '2',
				'style' => '',
			),
			1 =>
			array(
				'cells' => '1',
				'style' => '',
			),
		),

		'grid_cells' =>
		array(
			0 =>
			array(
				'weight' => '0.33',
				'grid'   => '0',
			),
			1 =>
			array(
				'weight' => '0.66',
				'grid'   => '0',
			),
			2 =>
			array(
				'weight' => '1',
				'grid'   => '1',
			),
		),
	);

	$layouts['magazine'] = array (
		'name'        => esc_html__( 'Magazine', 'reviewpro' ),
		'description' => esc_html__( 'Magazine layout for home page.', 'reviewpro' ),
		'screenshot'  => get_template_directory_uri() . '/screenshot.png',
		'widgets' =>
		array(
			0 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Vertical_Block',
					'id'    => '1',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
			1 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Vertical_Block',
					'id'    => '2',
					'grid'  => '0',
					'cell'  => '1',
				),
			),
			2 =>
			array(
				'title'     => esc_html__( 'Recent Posts', 'reviewpro' ),
				'text'      => esc_html__( 'Display recent posts with thumbnails.', 'reviewpro' ),
				'show_date' => true,
				'style'     => 'big-thumbnail',
				'number'    => 3,
				'info'  => array(
					'class' => 'ReviewPro_Recent_Widget',
					'id'    => '3',
					'grid'  => '0',
					'cell'  => '2',
				),
			),
			3 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Vertical_Block',
					'id'    => '4',
					'grid'  => '1',
					'cell'  => '0',
				),
			),
			4 =>
			array(
				'text' => esc_html__( 'Display grid style posts list.', 'reviewpro' ),
				'number' => 4,
				'column' => 'two-columns',
				'info'  => array(
					'class' => 'ReviewPro_Grid_Block',
					'id'    => '5',
					'grid'  => '1',
					'cell'  => '1',
				),
			),
			5 =>
			array(
				'text'   => esc_html__( 'Display grid classic style posts list.', 'reviewpro' ),
				'column' => 'four-columns',
				'number' => 4,
				'info'  => array(
					'class' => 'ReviewPro_Grid_Classic_Block',
					'id'    => '6',
					'grid'  => '2',
					'cell'  => '0',
				),
			),
			6 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Block',
					'id'    => '7',
					'grid'  => '3',
					'cell'  => '0',
				),
			),
			7 =>
			array(
				'title' => esc_html__( 'Video of the day', 'reviewpro' ),
				'info'  => array(
					'class' => 'ReviewPro_Video_Widget',
					'id'    => '8',
					'grid'  => '3',
					'cell'  => '1',
				),
			),
			8 =>
			array(
				'title'     => esc_html__( 'Random Posts', 'reviewpro' ),
				'text'      => esc_html__( 'Display random posts with thumbnails.', 'reviewpro' ),
				'show_date' => true,
				'style'     => 'big-thumbnail',
				'limit'     => 4,
				'info'  => array(
					'class' => 'ReviewPro_Random_Widget',
					'id'    => '9',
					'grid'  => '4',
					'cell'  => '0',
				),
			),
			9 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Horizontal_Block',
					'id'    => '10',
					'grid'  => '4',
					'cell'  => '1',
				),
			),
			10 =>
			array(
				'info'  => array(
					'class' => 'ReviewPro_Modern_Block',
					'id'    => '11',
					'grid'  => '4',
					'cell'  => '1',
				),
			),
			11 =>
			array(
				'text' => esc_html__( 'Display carousel style posts list.', 'reviewpro' ),
				'info'  => array(
					'class' => 'ReviewPro_Carousel_Block',
					'id'    => '12',
					'grid'  => '5',
					'cell'  => '0',
				),
			),
		),

		'grids' =>
		array(
			0 =>
			array(
				'cells' => '3',
				'style' => '',
			),
			1 =>
			array(
				'cells' => '2',
				'style' => '',
			),
			2 =>
			array(
				'cells' => '1',
				'style' => '',
			),
			3 =>
			array(
				'cells' => '2',
				'style' => '',
			),
			4 =>
			array(
				'cells' => '2',
				'style' => '',
			),
			5 =>
			array(
				'cells' => '1',
				'style' => '',
			),
		),

		'grid_cells' =>
		array(
			0 =>
			array(
				'weight' => '0.365',
				'grid'   => '0',
			),
			1 =>
			array(
				'weight' => '0.365',
				'grid'   => '0',
			),
			2 =>
			array(
				'weight' => '0.27',
				'grid'   => '0',
			),
			3 =>
			array(
				'weight' => '0.5',
				'grid'   => '1',
			),
			4 =>
			array(
				'weight' => '0.5',
				'grid'   => '1',
			),
			5 =>
			array(
				'weight' => '1',
				'grid'   => '2',
			),
			6 =>
			array(
				'weight' => '0.60',
				'grid'   => '3',
			),
			7 =>
			array(
				'weight' => '0.40',
				'grid'   => '3',
			),
			8 =>
			array(
				'weight' => '0.333',
				'grid'   => '4',
			),
			9 =>
			array(
				'weight' => '0.667',
				'grid'   => '4',
			),
			10 =>
			array(
				'weight' => '1',
				'grid'   => '5',
			),
		),
	);

	return $layouts;

}
add_filter( 'siteorigin_panels_prebuilt_layouts', 'reviewpro_prebuilt_page_layouts' );
