<?php
/**
 * Carousel block.
 *
 * @package    ReviewPro
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class ReviewPro_Carousel_Block extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'reviewpro_carousel_block',
			'description' => esc_html__( 'Display carousel style posts list.', 'reviewpro' )
		);

		// Create the widget.
		parent::__construct(
			'reviewpro_carousel_block',                  // $this->id_base
			esc_html__( 'Carousel Block', 'reviewpro' ), // $this->name
			$widget_options                              // $this->widget_options
		);

		$this->alt_option_name = 'reviewpro_carousel_block';
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		// Set up default value
		$cat = ( ! empty( $instance['cat'] ) ) ? $instance['cat'] : '';
		$num = ( ! empty( $instance['number'] ) ) ? intval( $instance['number'] ) : 3;
		if ( ! $num ) {
			$num = 3;
		}
		$col = ( ! empty( $instance['column'] ) ) ? esc_attr( $instance['column'] ) : 'three-columns';
		$size = '';
		if ( $col === 'three-columns' ) {
			$size  = 'medium';
			$width = 225;
			$items = 3;
		} elseif ( $col === 'four-columns' ) {
			$size  = 'medium';
			$width = 267;
			$items = 4;
		} elseif ( $col === 'two-columns' ) {
			$size = 'post-thumbnail';
			$width = 361;
			$items = 2;
		}

		// Output the theme's $before_widget wrapper.
		echo $args['before_widget'];

			if ( $cat ) :

				// Pull the selected category.
				$cat_id = intval( $cat );

				// Get the category.
				$category = get_category( $cat_id );

				// Get the category archive link.
				$cat_link = get_category_link( $cat_id );

				// Get the category color
				$color = reviewpro_get_term_color( $cat_id, true );
				$color = $color ? $color : '#1976D2';

				// Posts query arguments.
				$query = array(
					'posts_per_page' => $num,
					'post_type'      => 'post',
					'cat'            => $cat
				);

				// Allow dev to filter the post arguments.
				$query = apply_filters( 'reviewpro_carousel_block_arg', $query );

				// The post query.
				$posts = new WP_Query( $query );

				if ( $posts->have_posts() ) : ?>

					<?php $this->reviewpro_carousel_script( $width, $items, sprintf( ( '%1$s-%2$s' ), $this->id, $cat_id ) ); ?>

					<div class="carousel-block <?php echo $col; ?>">

						<h4 class="section-title" style="border-color: <?php echo $color; ?>">
							<span class="cat-name" style="background-color: <?php echo $color; ?>"><a href="<?php echo esc_url( $cat_link ); ?>"><?php echo esc_html( $category->name ); ?></a></span>
						</h4>

						<div class="carousel-posts flexslider <?php printf( ( '%1$s-%2$s' ), $this->id, $cat_id ); ?>">
							<div class="loading loader"></div>
							<ul class="slides">

								<?php while ( $posts->have_posts() ) : $posts->the_post(); ?>

									<li>
										<?php if ( has_post_thumbnail() ) : ?>
											<a class="thumbnail-link" href="<?php the_permalink(); ?>">
												<?php the_post_thumbnail( $size, array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
												<?php
													// Get the review score
													$type   = get_post_meta( get_the_ID(), 'tj_review_type', true );
													$review = get_post_meta( get_the_ID(), 'tj_review_feature', true );
													$avg = reviewpro_review_avg( array( 'type' => $type, 'count' => $review, 'progressbar' => true ) );
													if ( $avg ) :
												?>
													<span class="post-review">
														<span class="review-score">
															<span class="bar" style="width: <?php echo $avg . '%'; ?>"></span>
														</span>
													</span>
												<?php endif; ?>
											</a>
										<?php endif; ?>
										<?php the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" rel="bookmark" itemprop="url">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
										<?php reviewpro_posted_on(); ?>
									</li>

								<?php endwhile; ?>

							</ul>
						</div>

					</div>

				<?php endif;

				// Restore original Post Data.
				wp_reset_postdata();

			endif;

		// Close the theme's widget wrapper.
		echo $args['after_widget'];

	}

	/**
	 * Flexslider script
	 */
	function reviewpro_carousel_script( $width, $items, $class ) {
		?>
			<script>
				jQuery( window ).load( function () {
					jQuery( '.<?php echo $class; ?>' ).flexslider( {
						animation: "slide",
						animationLoop: false,
						itemWidth: <?php echo $width; ?>,
						itemMargin: 20,
						maxItems: <?php echo $items; ?>,
						start: function( slider ) {
							jQuery( '.loading' ).removeClass( 'loader' );
						}

					} );
				} );
			</script>
		<?php
	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['cat'] = intval( $new_instance['cat'] );
		$instance['number'] = (int) $new_instance['number'];
		$instance['column'] = isset( $new_instance['column'] ) ? esc_attr( $new_instance['column'] ) : 'three-columns';
		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	public function form( $instance ) {
		$cat = isset( $instance['cat'] ) ? intval( $instance['cat'] ) : '';
		$num = isset( $instance['number'] ) ? absint( $instance['number'] ) : 6;
		$col = isset( $instance['column'] ) ? esc_attr( $instance['column'] ) : 'three-columns';
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'cat' ); ?>"><?php esc_html_e( 'Choose Category:', 'reviewpro' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'cat' ); ?>" name="<?php echo $this->get_field_name( 'cat' ); ?>" style="width:100%;">
				<?php $categories = get_terms( 'category' ); ?>
				<?php foreach( $categories as $category ) { ?>
					<option value="<?php echo absint( $category->term_id ); ?>" <?php selected( $cat, absint( $category->term_id ) ); ?>><?php echo esc_html( $category->name ); ?></option>
				<?php } ?>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php esc_html_e( 'Number of posts to show:', 'reviewpro' ); ?></label>
			<input class="tiny-text" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="number" step="1" min="1" value="<?php echo $num; ?>" size="3" />
		</p>

		<p>
			<label for=""><?php esc_html_e( 'Columns', 'reviewpro' ); ?></label>
			<ul>
				<li>
					<input class="radio" type="radio" value="two-columns" <?php checked( $col, 'two-columns' ); ?> id="<?php echo $this->get_field_id( 'column' ); ?>-two" name="<?php echo $this->get_field_name( 'column' ); ?>" />
					<label for="<?php echo $this->get_field_id( 'column' ); ?>-two">
						<?php esc_html_e( 'Two Columns', 'reviewpro' ); ?>
					</label>
				</li>
				<li>
					<input class="radio" type="radio" value="three-columns" <?php checked( $col, 'three-columns' ); ?> id="<?php echo $this->get_field_id( 'column' ); ?>-three" name="<?php echo $this->get_field_name( 'column' ); ?>" />
					<label for="<?php echo $this->get_field_id( 'column' ); ?>-three">
						<?php esc_html_e( 'Three Columns', 'reviewpro' ); ?>
					</label>
				</li>
				<li>
					<input class="radio" type="radio" value="four-columns" <?php checked( $col, 'four-columns' ); ?> id="<?php echo $this->get_field_id( 'column' ); ?>-four" name="<?php echo $this->get_field_name( 'column' ); ?>" />
					<label for="<?php echo $this->get_field_id( 'column' ); ?>-four">
						<?php esc_html_e( 'Four Columns', 'reviewpro' ); ?>
					</label>
				</li>
			</ul>
		</p>

		<p><em><?php esc_html_e( 'Four columns is best in full width Row', 'reviewpro' ); ?></em></p>

	<?php

	}

}
