<?php
/**
 * Register custom customizer panels, sections and settings.
 *
 * @package    ReviewPro
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * We register our custom customizer by using the hook.
 *
 * @since  1.0.0
 */
function reviewpro_customizer_register() {

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// ======= Start Customizer Panels/Sections/Settings ======= //

	// General Panels and Sections
	$general_panel = 'general';

	$panels[] = array(
		'id'          => $general_panel,
		'title'       => esc_html__( 'General', 'reviewpro' ),
		'description' => esc_html__( 'This panel is used for managing general section of your site.', 'reviewpro' ),
		'priority'    => 10
	);

		// RSS
		$section = PREFIX . 'rss-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'RSS', 'reviewpro' ),
			'priority'    => 100,
			'panel'       => $general_panel,
			'description' => esc_html__( 'If you fill the custom rss url below, it will replace the default.', 'reviewpro' ),
		);
		$options[PREFIX . 'custom-rss'] = array(
			'id'           => PREFIX . 'custom-rss',
			'label'        => esc_html__( 'Custom RSS URL (eg. Feedburner)', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'url',
			'default'      => ''
		);

		// Comment
		$section = PREFIX . 'comment-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Comments', 'reviewpro' ),
			'priority'    => 110,
			'panel'       => $general_panel,
		);
		$options[PREFIX . 'page-comment'] = array(
			'id'           => PREFIX . 'page-comment',
			'label'        => esc_html__( 'Page Comment', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'switch',
			'default'      => 1
		);

		// Footer Text
		$section = PREFIX . 'footer-text-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Footer Text', 'reviewpro' ),
			'priority'    => 120,
			'panel'       => $general_panel,
		);
		$options[PREFIX . 'footer-text'] = array(
			'id'           => PREFIX . 'footer-text',
			'label'        => '',
			'description'  => esc_html__( 'Customize the footer text.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'textarea',
			'default'      => '&copy; Copyright ' . date( 'Y' ) . ' <a href="' . esc_url( home_url() ) . '">' . esc_attr( get_bloginfo( 'name' ) ) . '</a> &middot; Designed by <a href="http://www.theme-junkie.com/">Theme Junkie</a>'
		);

	// Header Panels and Sections
	$header_panel = 'header';

	$panels[] = array(
		'id'          => $header_panel,
		'title'       => esc_html__( 'Header', 'reviewpro' ),
		'description' => esc_html__( 'This panel is used for managing header section of your site.', 'reviewpro' ),
		'priority'    => 15
	);

		// Logo
		$section = PREFIX . 'logo-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Logo', 'reviewpro' ),
			'priority'    => 30,
			'panel'       => $header_panel
		);
		$options[PREFIX . 'logo'] = array(
			'id'      => PREFIX . 'logo',
			'label'   => esc_html__( 'Regular Logo', 'reviewpro' ),
			'section' => $section,
			'type'    => 'media',
			'default' => ''
		);

		// Search
		$section = PREFIX . 'search-header-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Search', 'reviewpro' ),
			'priority'    => 120,
			'panel'       => $header_panel,
		);
		$options[PREFIX . 'search-header'] = array(
			'id'           => PREFIX . 'search-header',
			'label'        => esc_html__( 'Enable search form', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'switch',
			'default'      => 1
		);

		// Social header
		$section = PREFIX . 'social-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Social', 'reviewpro' ),
			'priority'    => 125,
			'panel'       => $header_panel
		);
		$options[PREFIX . 'social-header'] = array(
			'id'           => PREFIX . 'social-header',
			'label'        => esc_html__( 'Header', 'reviewpro' ),
			'description'  => esc_html__( 'Display social icons in header.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'switch',
			'default'      => 1
		);
		$options[PREFIX . 'social-footer'] = array(
			'id'           => PREFIX . 'social-footer',
			'label'        => esc_html__( 'Footer', 'reviewpro' ),
			'description'  => esc_html__( 'Display social icons in footer.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'switch',
			'default'      => 1
		);
		$options[PREFIX . 'twitter'] = array(
			'id'      => PREFIX . 'twitter',
			'label'   => esc_html__( 'Twitter URL', 'reviewpro' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'facebook'] = array(
			'id'      => PREFIX . 'facebook',
			'label'   => esc_html__( 'Facebook URL', 'reviewpro' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'gplus'] = array(
			'id'      => PREFIX . 'gplus',
			'label'   => esc_html__( 'Google Plus URL', 'reviewpro' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'instagram'] = array(
			'id'      => PREFIX . 'instagram',
			'label'   => esc_html__( 'Instagram URL', 'reviewpro' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'pinterest'] = array(
			'id'      => PREFIX . 'pinterest',
			'label'   => esc_html__( 'Pinterest URL', 'reviewpro' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'linkedin'] = array(
			'id'      => PREFIX . 'linkedin',
			'label'   => esc_html__( 'LinkedIn URL', 'reviewpro' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'youtube'] = array(
			'id'      => PREFIX . 'youtube',
			'label'   => esc_html__( 'Youtube URL', 'reviewpro' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'vk'] = array(
			'id'      => PREFIX . 'vk',
			'label'   => esc_html__( 'VK URL', 'reviewpro' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[PREFIX . 'rss'] = array(
			'id'      => PREFIX . 'rss',
			'label'   => esc_html__( 'RSS URL', 'reviewpro' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);

	// Colors Panel and Sections
	$color_panel = 'color';

	$panels[] = array(
		'id'          => $color_panel,
		'title'       => esc_html__( 'Color', 'reviewpro' ),
		'description' => esc_html__( 'This panel is used for managing colors of your site.', 'reviewpro' ),
		'priority'    => 20
	);

	// Typography Panel and Sections
	$typo_panel = 'typography';

	$panels[] = array(
		'id'          => $typo_panel,
		'title'       => esc_html__( 'Typography', 'reviewpro' ),
		'description' => esc_html__( 'This panel is used for managing typography of your site.', 'reviewpro' ),
		'priority'    => 30
	);

		// Global typography
		$section = PREFIX . 'global-typography';
		$font_choices = customizer_library_get_font_choices();

		$sections[] = array(
			'id'       => $section,
			'title'    => esc_html__( 'Global', 'reviewpro' ),
			'priority' => 5,
			'panel'    => $typo_panel
		);
		$options[PREFIX . 'text-font'] = array(
			'id'          => PREFIX . 'text-font',
			'label'       => esc_html__( 'Text font', 'reviewpro' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => $font_choices,
			'default'     => 'Merriweather',
		);
		$options[PREFIX . 'heading-font'] = array(
			'id'          => PREFIX . 'heading-font',
			'label'       => esc_html__( 'Heading font', 'reviewpro' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => $font_choices,
			'default'     => 'Open Sans',
		);

	// Content Panel and Sections
	$content_panel = 'content';

	$panels[] = array(
		'id'          => $content_panel,
		'title'       => esc_html__( 'Contents', 'reviewpro' ),
		'description' => esc_html__( 'This panel is used for managing several custom content of your site.', 'reviewpro' ),
		'priority'    => 35
	);

		// Featured posts
		$section = PREFIX . 'featured-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Featured Posts', 'reviewpro' ),
			'priority'    => 5,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'featured-enable'] = array(
			'id'          => PREFIX . 'featured-enable',
			'label'       => esc_html__( 'Show featured posts', 'reviewpro' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'featured-tag'] = array(
			'id'          => PREFIX . 'featured-tag',
			'label'       => esc_html__( 'Select a tag', 'reviewpro' ),
			'description' => esc_html__( 'If you are not selecting any tag, the featured posts will display the most recent posts.', 'reviewpro' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => reviewpro_tags_list()
		);
		$options[PREFIX . 'featured-num'] = array(
			'id'          => PREFIX . 'featured-num',
			'label'       => esc_html__( 'Number of posts', 'reviewpro' ),
			'section'     => $section,
			'type'        => 'text',
			'default'     => 6
		);
		$options[PREFIX . 'featured-orderby'] = array(
			'id'          => PREFIX . 'featured-orderby',
			'label'       => esc_html__( 'Order by', 'reviewpro' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'date',
			'choices'     => array(
				'date'  => esc_html__( 'Date', 'reviewpro' ),
				'rand'  => esc_html__( 'Random', 'reviewpro' )
			)
		);

		// Posts
		$section = PREFIX . 'posts-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Posts', 'reviewpro' ),
			'priority'    => 10,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'post-share'] = array(
			'id'          => PREFIX . 'post-share',
			'label'       => __( 'Post share', 'reviewpro' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'post-navigation'] = array(
			'id'          => PREFIX . 'post-navigation',
			'label'       => __( 'Post navigation', 'reviewpro' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'post-author-box'] = array(
			'id'          => PREFIX . 'post-author-box',
			'label'       => __( 'Author box', 'reviewpro' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'related-posts-group'] = array(
			'id'          => PREFIX . 'related-posts-group',
			'label'       => esc_html__( 'Related Posts', 'reviewpro' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'related-posts'] = array(
				'id'          => PREFIX . 'related-posts',
				'label'       => esc_html__( 'Related posts', 'reviewpro' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'related-posts-number'] = array(
				'id'          => PREFIX . 'related-posts-number',
				'label'       => esc_html__( 'Number of posts to show', 'reviewpro' ),
				'section'     => $section,
				'type'        => 'number',
				'default'     => 3
			);

		$options[PREFIX . 'like-posts-group'] = array(
			'id'          => PREFIX . 'like-posts-group',
			'label'       => esc_html__( 'You Might Like', 'reviewpro' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'like-posts'] = array(
				'id'          => PREFIX . 'like-posts',
				'label'       => esc_html__( 'You might like', 'reviewpro' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'like-posts-number'] = array(
				'id'          => PREFIX . 'like-posts-number',
				'label'       => esc_html__( 'Number of posts to show', 'reviewpro' ),
				'section'     => $section,
				'type'        => 'number',
				'default'     => 3
			);

	// Container Section
	$section = PREFIX . 'container-section';

	$sections[] = array(
		'id'          => $section,
		'title'       => esc_html__( 'Container', 'reviewpro' ),
		'priority'    => 75
	);
	$options[PREFIX . 'container-layouts'] = array(
		'id'          => PREFIX . 'container-layouts',
		'label'       => esc_html__( 'Container layouts', 'reviewpro' ),
		'section'     => $section,
		'type'        => 'radio',
		'default'     => 'fullwidth',
		'choices'     => array(
			'fullwidth' => esc_html__( 'Full Width', 'reviewpro' ),
			'boxed'     => esc_html__( 'Boxed', 'reviewpro' ),
			'framed'    => esc_html__( 'Framed', 'reviewpro' )
		)
	);

	// Advertisement Panel and Sections
	$ads_panel = 'advertisement';

	$panels[] = array(
		'id'       => $ads_panel,
		'title'    => esc_html__( 'Advertisement', 'reviewpro' ),
		'priority' => 80
	);

		// Top ads
		$section = PREFIX . 'top-ads-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Top', 'reviewpro' ),
			'priority'    => 5,
			'panel'       => $ads_panel,
		);
		$options[PREFIX . 'top-ads-image'] = array(
			'id'           => PREFIX . 'top-ads-image',
			'label'        => esc_html__( 'Ads Image', 'reviewpro' ),
			'description'  => esc_html__( 'Upload your ads image then put the url in the setting below.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'media',
			'default'      => '',
		);
		$options[PREFIX . 'top-ads-url'] = array(
			'id'           => PREFIX . 'top-ads-url',
			'label'        => esc_html__( 'Ads URL', 'reviewpro' ),
			'description'  => esc_html__( 'Put the ads url in the box below.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'url',
			'default'      => ''
		);
		$options[PREFIX . 'top-ads-custom'] = array(
			'id'                => PREFIX . 'top-ads-custom',
			'label'             => esc_html__( 'Or', 'reviewpro' ),
			'description'       => esc_html__( 'Pur you custom ads code (eg. adsense) in the box below.', 'reviewpro' ),
			'section'           => $section,
			'type'              => 'textarea',
			'sanitize_callback' => 'reviewpro_textarea_stripslashes',
			'default'           => ''
		);

		// Header ads
		$section = PREFIX . 'header-ads-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Header Right', 'reviewpro' ),
			'priority'    => 5,
			'panel'       => $ads_panel,
		);
		$options[PREFIX . 'header-ads-image'] = array(
			'id'           => PREFIX . 'header-ads-image',
			'label'        => esc_html__( 'Ads Image', 'reviewpro' ),
			'description'  => esc_html__( 'Upload your ads image then put the url in the setting below.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'media',
			'default'      => '',
		);
		$options[PREFIX . 'header-ads-url'] = array(
			'id'           => PREFIX . 'header-ads-url',
			'label'        => esc_html__( 'Ads URL', 'reviewpro' ),
			'description'  => esc_html__( 'Put the ads url in the box below.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'url',
			'default'      => ''
		);
		$options[PREFIX . 'header-ads-custom'] = array(
			'id'                => PREFIX . 'header-ads-custom',
			'label'             => esc_html__( 'Or', 'reviewpro' ),
			'description'       => esc_html__( 'Pur you custom ads code (eg. adsense) in the box below.', 'reviewpro' ),
			'section'           => $section,
			'type'              => 'textarea',
			'sanitize_callback' => 'reviewpro_textarea_stripslashes',
			'default'           => ''
		);

		// After menu ads
		$section = PREFIX . 'after-menu-ads-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'After Menu', 'reviewpro' ),
			'priority'    => 5,
			'panel'       => $ads_panel,
		);
		$options[PREFIX . 'after-menu-ads-image'] = array(
			'id'           => PREFIX . 'after-menu-ads-image',
			'label'        => esc_html__( 'Ads Image', 'reviewpro' ),
			'description'  => esc_html__( 'Upload your ads image then put the url in the setting below.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'media',
			'default'      => '',
		);
		$options[PREFIX . 'after-menu-ads-url'] = array(
			'id'           => PREFIX . 'after-menu-ads-url',
			'label'        => esc_html__( 'Ads URL', 'reviewpro' ),
			'description'  => esc_html__( 'Put the ads url in the box below.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'url',
			'default'      => ''
		);
		$options[PREFIX . 'after-menu-ads-custom'] = array(
			'id'                => PREFIX . 'after-menu-ads-custom',
			'label'             => esc_html__( 'Or', 'reviewpro' ),
			'description'       => esc_html__( 'Pur you custom ads code (eg. adsense) in the box below.', 'reviewpro' ),
			'section'           => $section,
			'type'              => 'textarea',
			'sanitize_callback' => 'reviewpro_textarea_stripslashes',
			'default'           => ''
		);

		// Single post ads before content
		$section = PREFIX . 'posts-ads-before-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Post before content', 'reviewpro' ),
			'description' => esc_html__( 'Single post advertisement before content', 'reviewpro' ),
			'priority'    => 10,
			'panel'       => $ads_panel,
		);
		$options[PREFIX . 'post-ads-image-before'] = array(
			'id'           => PREFIX . 'post-ads-image-before',
			'label'        => esc_html__( 'Ads Image', 'reviewpro' ),
			'description'  => esc_html__( 'Upload your ads image then put the url in the setting below.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'media',
			'default'      => '',
		);
		$options[PREFIX . 'post-ads-url-before'] = array(
			'id'           => PREFIX . 'post-ads-url-before',
			'label'        => esc_html__( 'Ads URL', 'reviewpro' ),
			'description'  => esc_html__( 'Put the ads url in the box below.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'url',
			'default'      => ''
		);
		$options[PREFIX . 'post-ads-custom-before'] = array(
			'id'                => PREFIX . 'post-ads-custom-before',
			'label'             => esc_html__( 'Or', 'reviewpro' ),
			'description'       => esc_html__( 'Pur you custom ads code (eg. adsense) in the box below.', 'reviewpro' ),
			'section'           => $section,
			'type'              => 'textarea',
			'sanitize_callback' => 'reviewpro_textarea_stripslashes',
			'default'           => ''
		);
		$options[PREFIX . 'post-ads-position-before'] = array(
			'id'           => PREFIX . 'post-ads-position-before',
			'label'        => esc_html__( 'Position', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'radio',
			'default'      => 'default',
			'choices'      => array(
				'default' => esc_html__( 'Default Block', 'reviewpro' ),
				'center'  => esc_html__( 'Center Block', 'reviewpro' ),
				'right'   => esc_html__( 'Right Block', 'reviewpro' ),
				'f-left'  => esc_html__( 'Float Left', 'reviewpro' ),
				'f-right' => esc_html__( 'Float Right', 'reviewpro' ),
			)
		);

		// Single post ads after content
		$section = PREFIX . 'posts-ads-after-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Post after content', 'reviewpro' ),
			'description' => esc_html__( 'Single post advertisement after content', 'reviewpro' ),
			'priority'    => 15,
			'panel'       => $ads_panel,
		);
		$options[PREFIX . 'post-ads-image-after'] = array(
			'id'           => PREFIX . 'post-ads-image-after',
			'label'        => esc_html__( 'Ads Image', 'reviewpro' ),
			'description'  => esc_html__( 'Upload your ads image then put the url in the setting below.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'media',
			'default'      => '',
		);
		$options[PREFIX . 'post-ads-url-after'] = array(
			'id'           => PREFIX . 'post-ads-url-after',
			'label'        => esc_html__( 'Ads URL', 'reviewpro' ),
			'description'  => esc_html__( 'Put the ads url in the box below.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'url',
			'default'      => ''
		);
		$options[PREFIX . 'post-ads-custom-after'] = array(
			'id'                => PREFIX . 'post-ads-custom-after',
			'label'             => esc_html__( 'Or', 'reviewpro' ),
			'description'       => esc_html__( 'Pur you custom ads code (eg. adsense) in the box below.', 'reviewpro' ),
			'section'           => $section,
			'type'              => 'textarea',
			'sanitize_callback' => 'reviewpro_textarea_stripslashes',
			'default'           => ''
		);
		$options[PREFIX . 'post-ads-position-after'] = array(
			'id'           => PREFIX . 'post-ads-position-after',
			'label'        => esc_html__( 'Position', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'radio',
			'default'      => 'default',
			'choices'      => array(
				'default' => esc_html__( 'Default Block', 'reviewpro' ),
				'center'  => esc_html__( 'Center Block', 'reviewpro' ),
				'right'   => esc_html__( 'Right Block', 'reviewpro' )
			)
		);

		// Single post ads after paragraph
		$section = PREFIX . 'posts-ads-after-paragraph-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Post after paragraph', 'reviewpro' ),
			'description' => esc_html__( 'Single post advertisement after x paragraph', 'reviewpro' ),
			'priority'    => 20,
			'panel'       => $ads_panel,
		);
		$options[PREFIX . 'post-ads-image-after-paragraph'] = array(
			'id'           => PREFIX . 'post-ads-image-after-paragraph',
			'label'        => esc_html__( 'Ads Image', 'reviewpro' ),
			'description'  => esc_html__( 'Upload your ads image then put the url in the setting below.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'media',
			'default'      => '',
		);
		$options[PREFIX . 'post-ads-url-after-paragraph'] = array(
			'id'           => PREFIX . 'post-ads-url-after-paragraph',
			'label'        => esc_html__( 'Ads URL', 'reviewpro' ),
			'description'  => esc_html__( 'Put the ads url in the box below.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'url',
			'default'      => ''
		);
		$options[PREFIX . 'post-ads-custom-after-paragraph'] = array(
			'id'                => PREFIX . 'post-ads-custom-after-paragraph',
			'label'             => esc_html__( 'Or', 'reviewpro' ),
			'description'       => esc_html__( 'Pur you custom ads code (eg. adsense) in the box below.', 'reviewpro' ),
			'section'           => $section,
			'type'              => 'textarea',
			'sanitize_callback' => 'reviewpro_textarea_stripslashes',
			'default'           => ''
		);
		$options[PREFIX . 'post-ads-paragraph-after-paragraph'] = array(
			'id'           => PREFIX . 'post-ads-paragraph-after-paragraph',
			'label'        => esc_html__( 'After Paragraph', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'radio',
			'default'      => '1',
			'choices'      => array(
				'1' => esc_html__( 'One', 'reviewpro' ),
				'2' => esc_html__( 'Two', 'reviewpro' ),
				'3' => esc_html__( 'Three', 'reviewpro' ),
				'4' => esc_html__( 'Four', 'reviewpro' ),
				'5' => esc_html__( 'Five', 'reviewpro' )
			)
		);
		$options[PREFIX . 'post-ads-position-after-paragraph'] = array(
			'id'           => PREFIX . 'post-ads-position-after-paragraph',
			'label'        => esc_html__( 'Position', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'radio',
			'default'      => 'default',
			'choices'      => array(
				'default' => esc_html__( 'Default Block', 'reviewpro' ),
				'center'  => esc_html__( 'Center Block', 'reviewpro' ),
				'right'   => esc_html__( 'Right Block', 'reviewpro' ),
				'f-left'  => esc_html__( 'Float Left', 'reviewpro' ),
				'f-right' => esc_html__( 'Float Right', 'reviewpro' ),
			)
		);

		// Footer ads
		$section = PREFIX . 'footer-ads-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Footer', 'reviewpro' ),
			'priority'    => 25,
			'panel'       => $ads_panel,
		);
		$options[PREFIX . 'footer-ads-image'] = array(
			'id'           => PREFIX . 'footer-ads-image',
			'label'        => esc_html__( 'Ads Image', 'reviewpro' ),
			'description'  => esc_html__( 'Upload your ads image then put the url in the setting below.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'media',
			'default'      => '',
		);
		$options[PREFIX . 'footer-ads-url'] = array(
			'id'           => PREFIX . 'footer-ads-url',
			'label'        => esc_html__( 'Ads URL', 'reviewpro' ),
			'description'  => esc_html__( 'Put the ads url in the box below.', 'reviewpro' ),
			'section'      => $section,
			'type'         => 'url',
			'default'      => ''
		);
		$options[PREFIX . 'footer-ads-custom'] = array(
			'id'                => PREFIX . 'footer-ads-custom',
			'label'             => esc_html__( 'Or', 'reviewpro' ),
			'description'       => esc_html__( 'Pur you custom ads code (eg. adsense) in the box below.', 'reviewpro' ),
			'section'           => $section,
			'type'              => 'textarea',
			'sanitize_callback' => 'reviewpro_textarea_stripslashes',
			'default'           => ''
		);

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

}
add_action( 'init', 'reviewpro_customizer_register' );
