<?php
/**
 * Custom template tags for this theme.
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package    ReviewPro
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'reviewpro_site_branding' ) ) :
/**
 * Site branding for the site.
 *
 * Display site title by default, but user can change it with their custom logo.
 * They can upload it on Customizer page.
 *
 * @since  1.0.0
 */
function reviewpro_site_branding() {

	// Get the customizer value.
	$logo_id  = reviewpro_mod( PREFIX . 'logo' );

	// Check if logo available, then display it.
	if ( $logo_id ) :
		echo '<div id="logo" itemscope itemtype="http://schema.org/Brand">' . "\n";
			echo '<a class="site-logo" href="' . esc_url( get_home_url() ) . '" itemprop="url" rel="home">' . "\n";
				echo '<img itemprop="logo" src="' . esc_url( wp_get_attachment_url( $logo_id ) ) . '" alt="' . esc_attr( get_bloginfo( 'name' ) ) . '" />' . "\n";
			echo '</a>' . "\n";
		echo '</div>' . "\n";

	// If not, then display the Site Title and Site Description.
	else :
		echo '<div id="logo">'. "\n";
			echo '<h1 class="site-title" ' . hybrid_get_attr( 'site-title' ) . '><a href="' . esc_url( get_home_url() ) . '" itemprop="url" rel="home"><span itemprop="headline">' . esc_attr( get_bloginfo( 'name' ) ) . '</span></a></h1>'. "\n";
		echo '</div>'. "\n";
	endif;

}
endif;

if ( ! function_exists( 'reviewpro_social_icons' ) ) :
/**
 * Header social
 */
function reviewpro_social_icons( $position = 'header' ) {

	// Get the customizer data
	$tw        = reviewpro_mod( PREFIX . 'twitter' );
	$fb        = reviewpro_mod( PREFIX . 'facebook' );
	$gplus     = reviewpro_mod( PREFIX . 'gplus' );
	$instagram = reviewpro_mod( PREFIX . 'instagram' );
	$pinterest = reviewpro_mod( PREFIX . 'pinterest' );
	$linkedin  = reviewpro_mod( PREFIX . 'linkedin' );
	$youtube   = reviewpro_mod( PREFIX . 'youtube' );
	$vk        = reviewpro_mod( PREFIX . 'vk' );
	$rss       = reviewpro_mod( PREFIX . 'rss' );

	// Display the data
	if ( $tw || $fb || $gplus || $instagram || $pinterest || $youtube || $vk || $rss ) {

		echo '<div id="' . $position . '-social" class="social-icons">';
			if ( $tw ) {
				echo '<a class="twitter" href="' . esc_url( $tw ) . '"><i class="fa fa-twitter"></i></a> ';
			}
			if ( $fb ) {
				echo '<a class="facebook" href="' . esc_url( $fb ) . '"><i class="fa fa-facebook"></i></a> ';
			}
			if ( $gplus ) {
				echo '<a class="gplus" href="' . esc_url( $gplus ) . '"><i class="fa fa-google-plus"></i></a> ';
			}
			if ( $instagram ) {
				echo '<a class="instagram" href="' . esc_url( $instagram ) . '"><i class="fa fa-instagram"></i></a> ';
			}
			if ( $pinterest ) {
				echo '<a class="pinterest" href="' . esc_url( $pinterest ) . '"><i class="fa fa-pinterest"></i></a> ';
			}
			if ( $linkedin ) {
				echo '<a class="linkedin" href="' . esc_url( $linkedin ) . '"><i class="fa fa-linkedin"></i></a> ';
			}
			if ( $youtube ) {
				echo '<a class="youtube" href="' . esc_url( $youtube ) . '"><i class="fa fa-youtube"></i></a> ';
			}
			if ( $vk ) {
				echo '<a class="vk" href="' . esc_url( $vk ) . '"><i class="fa fa-vk"></i></a> ';
			}
			if ( $rss ) {
				echo '<a class="rss" href="' . esc_url( $rss ) . '"><i class="fa fa-rss"></i></a>';
			}
		echo '</div>';

	}

}
endif;

if ( ! function_exists( 'reviewpro_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 *
 * @since 1.0.0
 */
function reviewpro_posted_on() {
	?>
	<div class="entry-meta">
		<span class="entry-author" <?php hybrid_attr( 'entry-author' ); ?>>
			<?php printf( esc_html__( 'by %s', 'reviewpro' ), '<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '" itemprop="url"><span itemprop="name">' . esc_html( get_the_author() ) . '</span></a>' ) ?>
		</span>
		<time class="entry-date published" datetime="<?php echo esc_attr( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ); ?>><?php echo esc_html( get_the_date() ); ?></time>
	</div>
	<?php
}
endif;

if ( ! function_exists( 'reviewpro_categorized_blog' ) ) :
/**
 * Returns true if a blog has more than 1 category.
 *
 * @since  1.0.0
 * @return bool
 */
function reviewpro_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'reviewpro_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'reviewpro_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so reviewpro_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so reviewpro_categorized_blog should return false.
		return false;
	}
}
endif;

if ( ! function_exists( 'reviewpro_category_transient_flusher' ) ) :
/**
 * Flush out the transients used in reviewpro_categorized_blog.
 *
 * @since 1.0.0
 */
function reviewpro_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'reviewpro_categories' );
}
endif;
add_action( 'edit_category', 'reviewpro_category_transient_flusher' );
add_action( 'save_post',     'reviewpro_category_transient_flusher' );

if ( ! function_exists( 'reviewpro_post_category' ) ) :
/**
 * Post category.
 *
 * @since 1.0.0
 */
function reviewpro_post_category() {
	?>

		<?php if ( 'post' == get_post_type() ) : ?>
			<?php
				$categories = get_the_category();
				if ( $categories && reviewpro_categorized_blog() ) :
			?>
			<span class="cat-links" <?php hybrid_attr( 'entry-terms', 'category' ); ?>>
				<?php foreach( $categories as $category ) : ?>
					<?php $color = reviewpro_get_term_color( $category->term_id, true ); ?>
					<?php $color = $color ? $color : '#1976D2'; ?>
					<a href="<?php echo esc_url( get_category_link( $category->term_id ) ) ?>" style="background-color: <?php echo $color; ?>"><?php echo esc_html( $category->name ); ?></a>
				<?php endforeach; ?>
			</span>
			<?php endif; // End if categories ?>
		<?php endif; ?>

	<?php
}
endif;

if ( ! function_exists( 'reviewpro_first_category' ) ) :
/**
 * Prints the first category.
 *
 * @since 1.0.0
 */
function reviewpro_first_category() {
	?>

		<?php if ( 'post' == get_post_type() ) : ?>
			<?php
				$categories = get_the_category();
				if ( $categories && reviewpro_categorized_blog() ) :
			?>
			<span class="cat-links first-cat" <?php hybrid_attr( 'entry-terms', 'category' ); ?>>
				<?php $color = reviewpro_get_term_color( $categories[0]->term_id, true ); ?>
				<?php $color = $color ? $color : '#1976D2'; ?>
				<a href="<?php echo esc_url( get_category_link( $categories[0]->term_id ) ) ?>" style="background-color: <?php echo $color; ?>"><?php echo esc_html( $categories[0]->name ); ?></a>
			</span>
			<?php endif; // End if categories ?>
		<?php endif; ?>

	<?php
}
endif;

if ( ! function_exists( 'reviewpro_post_thumbnail' ) ) :
/**
 * Post thumbnail.
 *
 * @since 1.0.0
 */
function reviewpro_post_thumbnail() {

	// Set up default thumbnail size
	$size = 'medium';

	// Category layout
	if ( is_category() ) {

		// Get the list layout
		$list = reviewpro_get_term_meta( 'list_layout' );

		if ( $list === 'blog' ) {
			$size = 'large';
		} elseif ( $list === 'masonry' ) {
			$size = 'reviewpro-masonry';
		}

	}

	// Get the image attributes
	$attr = wp_get_attachment_image_src( get_post_thumbnail_id(), $size );

	?>
	<?php if ( has_post_thumbnail() ) : ?>
		<div class="thumbnail" itemprop="image" itemscope itemtype="https://schema.org/ImageObject">
			<a class="thumbnail-link" href="<?php the_permalink(); ?>">
				<?php the_post_thumbnail( $size, array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
			</a>
			<meta itemprop="url" content="<?php echo esc_url( $attr[0] ); ?>">
			<meta itemprop="width" content="<?php echo absint( $attr[1] ); ?>">
			<meta itemprop="height" content="<?php echo absint( $attr[2] ); ?>">
			<span class="format-icon"><?php echo reviewpro_format_icons(); ?></span>
		</div>
	<?php endif; ?>
	<?php
}
endif;

if ( ! function_exists( 'reviewpro_format_icons' ) ) :
/**
 * Post formats icon.
 *
 * @since 1.0.0
 */
function reviewpro_format_icons() {

	// Set up empty variable
	$icon = '';

	if ( has_post_format( 'audio' ) ) {
		$icon = '<i class="fa fa-music"></i>';
	} elseif ( has_post_format( 'video' ) ) {
		$icon = '<i class="fa fa-play"></i>';
	} elseif ( has_post_format( 'gallery' ) ) {
		$icon = '<i class="fa fa-camera-retro"></i>';
	}

	return $icon;

}
endif;

if ( ! function_exists( 'reviewpro_format_gallery' ) ) :
/**
 * Format gallery
 *
 * @since  1.0.0
 */
function reviewpro_format_gallery() {

	// Get the metabox data
	$images = get_post_meta( get_the_ID(), 'tj_format_gallery', true );

	// Display the gallery
	if ( $images ) {
		echo '<div class="format-gallery featured-posts flexslider">';
			echo '<ul class="slides images">';
				foreach( $images as $image ):
					echo '<li class="image">';
						echo wp_get_attachment_image( $image, 'large' );
					echo '</li>';
				endforeach;
			echo '</ul>';
		echo '</div>';
	}

}
endif;

if ( ! function_exists( 'reviewpro_format_video' ) ) :
/**
 * Format video
 *
 * @since  1.0.0
 */
function reviewpro_format_video() {

	// Get the metabox data
	$embed  = get_post_meta( get_the_ID(), 'tj_format_video_embed', true );
	$upload = get_post_meta( get_the_ID(), 'tj_format_video_upload', true );

	// Display the video
	if ( $embed ) {
		echo wp_oembed_get( $embed );
	} elseif ( $upload ) {
		// Get the video url/
		$url = wp_get_attachment_url( $upload );

		// Display the video.
		echo do_shortcode( '[video width="1050" src="' . $url . '"]' );
	}

}
endif;

if ( ! function_exists( 'reviewpro_format_audio' ) ) :
/**
 * Format audio
 *
 * @since  1.0.0
 */
function reviewpro_format_audio() {

	// Get the metabox data
	$embed  = get_post_meta( get_the_ID(), 'tj_format_audio_embed', true );
	$upload = get_post_meta( get_the_ID(), 'tj_format_audio_upload', true );

	// Display the audio
	if ( $embed ) {
		echo wp_oembed_get( $embed );
	} elseif ( $upload ) {
		// Get the audio url/
		$url = wp_get_attachment_url( $upload );

		// Display the audio.
		echo do_shortcode( '[audio width="1050" src="' . $url . '"]' );
	}

}
endif;

if ( ! function_exists( 'reviewpro_entry_share' ) ) :
/**
 * Social share.
 *
 * @since 1.0.0
 */
function reviewpro_entry_share() {

	// Get the data set in customizer
	$share  = reviewpro_mod( PREFIX . 'post-share' );

	if ( $share === 0 ) {
		return;
	}

	?>
		<div class="entry-share">
			<span class="share-title"><?php esc_html_e( 'Share:', 'reviewpro' ); ?></span>
			<ul>
				<li class="twitter"><a href="https://twitter.com/intent/tweet?text=<?php echo urlencode( esc_attr( get_the_title( get_the_ID() ) ) ); ?>&amp;url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-twitter"></i></a></li>
				<li class="facebook"><a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-facebook"></i></a></li>
				<li class="google-plus"><a href="https://plus.google.com/share?url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-google-plus"></i></a></li>
				<li class="linkedin"><a href="https://www.linkedin.com/shareArticle?mini=true&amp;url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>&amp;title=<?php echo urlencode( esc_attr( get_the_title( get_the_ID() ) ) ); ?>" target="_blank"><i class="fa fa-linkedin"></i></a></li>
				<li class="pinterest"><a href="https://pinterest.com/pin/create/button/?url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>&amp;media=<?php echo urlencode( wp_get_attachment_url( get_post_thumbnail_id( get_the_ID() ) ) ); ?>" target="_blank"><i class="fa fa-pinterest"></i></a></li>
				<li class="email"><a href="mailto:?subject=<?php echo esc_url( urlencode( '[' . get_bloginfo( 'name' ) . '] ' . get_the_title( get_the_ID() ) ) ); ?>&amp;body=<?php echo esc_url( urlencode( get_permalink( get_the_ID() ) ) ); ?>"><i class="fa fa-envelope"></i></a></li>
			</ul>
		</div>
	<?php
}
endif;

if ( ! function_exists( 'reviewpro_next_prev_post' ) ) :
/**
 * Custom next post link
 *
 * @since 1.0.0
 */
function reviewpro_next_prev_post() {

	// Get the data set in customizer
	$nav  = reviewpro_mod( PREFIX . 'post-navigation' );

	if ( $nav === 0 ) {
		return;
	}

	// Display on single post page.
	if ( ! is_single() ) {
		return;
	}

	// Get the next and previous post id.
	$next = get_adjacent_post( false, '', false );
	$prev = get_adjacent_post( false, '', true );
?>
	<div class="post-pagination">

		<?php if ( $prev ) : ?>
			<div class="prev-post">

				<?php if ( has_post_thumbnail( $prev->ID ) ) : ?>
					<a class="thumbnail-link" href="<?php echo esc_url( get_permalink( $prev->ID ) ); ?>"><?php echo get_the_post_thumbnail( $prev->ID, 'thumbnail', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title( $prev->ID ) ) ) ) ?></a>
				<?php endif; ?>

				<div class="post-detail">
					<span><?php esc_html_e( 'Previous Post', 'reviewpro' ); ?></span>
					<a href="<?php echo esc_url( get_permalink( $prev->ID ) ); ?>" class="post-title"><?php echo esc_attr( get_the_title( $prev->ID ) ); ?></a>
				</div>

			</div>
		<?php endif; ?>

		<?php if ( $next ) : ?>
			<div class="next-post">

				<?php if ( has_post_thumbnail( $next->ID ) ) : ?>
					<a class="thumbnail-link" href="<?php echo esc_url( get_permalink( $next->ID ) ); ?>"><?php echo get_the_post_thumbnail( $next->ID, 'thumbnail', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title( $next->ID ) ) ) ) ?></a>
				<?php endif; ?>

				<div class="post-detail">
					<span><?php esc_html_e( 'Next Post', 'reviewpro' ); ?></span>
					<a href="<?php echo esc_url( get_permalink( $next->ID ) ); ?>" class="post-title"><?php echo esc_attr( get_the_title( $next->ID ) ); ?></a>
				</div>

			</div>
		<?php endif; ?>

	</div>
<?php
}
endif;

if ( ! function_exists( 'reviewpro_entry_publisher' ) ) :
/**
 * Schema.org publisher
 */
function reviewpro_entry_publisher() {
	?>
	<div itemprop="publisher" itemscope itemtype="https://schema.org/Organization">
		<div itemprop="logo" itemscope itemtype="https://schema.org/ImageObject">
			<?php
			$logo_id = reviewpro_mod( PREFIX . 'logo' );
			if ( $logo_id ) {
				$logo_url = wp_get_attachment_url( $logo_id );
			} else {
				$logo_url = '//placehold.it/91x30';
			}
			?>
			<meta itemprop="url" content="<?php echo esc_url( $logo_url ); ?>">
			<meta itemprop="width" content="300">
			<meta itemprop="height" content="200">
		</div>
		<meta itemprop="name" content="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>">
	</div>
	<?php
}
endif;

if ( ! function_exists( 'reviewpro_post_author_box' ) ) :
/**
 * Author post informations.
 *
 * @since  1.0.0
 */
function reviewpro_post_author_box() {

	// Get the data set in customizer
	$enable = reviewpro_mod( PREFIX . 'post-author-box' );

	// Disable if user choose it.
	if ( $enable === 0 ) {
		return;
	}

	// Bail if not on the single post.
	if ( ! is_single() || is_attachment() ) {
		return;
	}

	// Bail if user hasn't fill the Biographical Info field.
	if ( ! get_the_author_meta( 'description' ) ) {
		return;
	}

	// Get the author social information.
	$url       = get_the_author_meta( 'url' );
	$twitter   = get_the_author_meta( 'twitter' );
	$facebook  = get_the_author_meta( 'facebook' );
	$gplus     = get_the_author_meta( 'gplus' );
	$instagram = get_the_author_meta( 'instagram' );
	$linkedin  = get_the_author_meta( 'linkedin' );
	$pinterest = get_the_author_meta( 'pinterest' );
?>

	<div class="author-bio clearfix" <?php hybrid_attr( 'entry-author' ) ?>>
		<?php echo get_avatar( is_email( get_the_author_meta( 'user_email' ) ), apply_filters( 'reviewpro_author_bio_avatar_size', 96 ), '', strip_tags( get_the_author() ) ); ?>
		<div class="description">

			<h3 class="author-title name">
				<a class="author-name url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" rel="author" itemprop="url"><span itemprop="name"><?php echo strip_tags( get_the_author() ); ?></span></a>
			</h3>

			<p class="bio" itemprop="description"><?php echo stripslashes( get_the_author_meta( 'description' ) ); ?></p>

			<?php if ( $url || $twitter || $facebook || $gplus || $instagram || $linkedin || $pinterest ) : ?>
				<ul class="author-social">
					<?php if ( $url ) : ?>
						<li class="website">
							<a href="<?php echo esc_url( $url ); ?>"><i class="fa fa-home"></i></a>
						</li>
					<?php endif; ?>
					<?php if ( $twitter ) : ?>
						<li class="twitter">
							<a href="<?php echo esc_url( $twitter ); ?>"><i class="fa fa-twitter"></i></a>
						</li>
					<?php endif; ?>
					<?php if ( $facebook ) : ?>
						<li class="facebook">
							<a href="<?php echo esc_url( $facebook ); ?>"><i class="fa fa-facebook"></i></a>
						</li>
					<?php endif; ?>
					<?php if ( $gplus ) : ?>
						<li class="gplus">
							<a href="<?php echo esc_url( $gplus ); ?>"><i class="fa fa-google-plus"></i></a>
						</li>
					<?php endif; ?>
					<?php if ( $instagram ) : ?>
						<li class="instagram">
							<a href="<?php echo esc_url( $instagram ); ?>"><i class="fa fa-instagram"></i></a>
						</li>
					<?php endif; ?>
					<?php if ( $linkedin ) : ?>
						<li class="linkedin">
							<a href="<?php echo esc_url( $linkedin ); ?>"><i class="fa fa-linkedin"></i></a>
						</li>
					<?php endif; ?>
					<?php if ( $pinterest ) : ?>
						<li class="pinterest">
							<a href="<?php echo esc_url( $pinterest ); ?>"><i class="fa fa-pinterest"></i></a>
						</li>
					<?php endif; ?>
				</ul>
			<?php endif; ?>

		</div>
	</div><!-- .author-bio -->

<?php
}
endif;

if ( ! function_exists( 'reviewpro_related_posts' ) ) :
/**
 * Related posts.
 *
 * @since  1.0.0
 */
function reviewpro_related_posts() {

	// Get the data set in customizer
	$enable  = reviewpro_mod( PREFIX . 'related-posts' );
	$number  = reviewpro_mod( PREFIX . 'related-posts-number' );

	// Disable if user choose it.
	if ( $enable === 0 ) {
		return;
	}

	// Get the taxonomy terms of the current page for the specified taxonomy.
	$terms = wp_get_post_terms( get_the_ID(), 'category', array( 'fields' => 'ids' ) );

	// Bail if the term empty.
	if ( empty( $terms ) ) {
		return;
	}

	// Posts query arguments.
	$query = array(
		'post__not_in' => array( get_the_ID() ),
		'tax_query'    => array(
			array(
				'taxonomy' => 'category',
				'field'    => 'id',
				'terms'    => $terms,
				'operator' => 'IN'
			)
		),
		'posts_per_page' => $number,
		'post_type'      => 'post',
	);

	// Allow dev to filter the query.
	$args = apply_filters( 'reviewpro_related_posts_args', $query );

	// The post query
	$related = new WP_Query( $args );

	if ( $related->have_posts() ) : ?>

		<div class="related-posts">
			<h3><?php esc_html_e( 'Related Articles', 'reviewpro' ); ?></h3>
			<ul>
				<?php while ( $related->have_posts() ) : $related->the_post(); ?>
					<li>
						<?php reviewpro_first_category(); ?>
						<?php if ( has_post_thumbnail() ) : ?>
							<a class="thumbnail-link" href="<?php the_permalink(); ?>">
								<?php the_post_thumbnail( 'medium', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
								<span class="img-overlay"></span>
							</a>
						<?php endif; ?>
						<div class="post-detail">
							<?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
							<?php reviewpro_posted_on(); ?>
						</div>
					</li>
				<?php endwhile; ?>
			</ul>
		</div>

	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();

}
endif;

if ( ! function_exists( 'reviewpro_also_like' ) ) :
/**
 * Related posts.
 *
 * @since  1.0.0
 */
function reviewpro_also_like() {

	// Get the data set in customizer
	$enable  = reviewpro_mod( PREFIX . 'like-posts' );
	$number  = reviewpro_mod( PREFIX . 'like-posts-number' );

	// Disable if user choose it.
	if ( $enable === 0 ) {
		return;
	}

	// Posts query arguments.
	$query = array(
		'post__not_in'   => array( get_the_ID() ),
		'orderby'        => 'rand',
		'posts_per_page' => $number,
		'post_type'      => 'post',
	);

	// Allow dev to filter the query.
	$args = apply_filters( 'reviewpro_random_posts_args', $query );

	// The post query
	$random = new WP_Query( $args );

	if ( $random->have_posts() ) : ?>

		<div class="random-posts related-posts">
			<h3><?php esc_html_e( 'You Might Also Like', 'reviewpro' ); ?></h3>
			<ul>
				<?php while ( $random->have_posts() ) : $random->the_post(); ?>
					<li>
						<?php reviewpro_first_category(); ?>
						<?php if ( has_post_thumbnail() ) : ?>
							<a class="thumbnail-link" href="<?php the_permalink(); ?>">
								<?php the_post_thumbnail( 'medium', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
								<span class="img-overlay"></span>
							</a>
						<?php endif; ?>
						<div class="post-detail">
							<?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
							<?php reviewpro_posted_on(); ?>
						</div>
					</li>
				<?php endwhile; ?>
			</ul>
		</div>

	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();

}
endif;

if ( ! function_exists( 'reviewpro_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since  1.0.0
 */
function reviewpro_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>
		<article id="comment-<?php comment_ID(); ?>" class="comment-container">
			<p <?php hybrid_attr( 'comment-content' ); ?>><?php esc_html_e( 'Pingback:', 'reviewpro' ); ?> <span <?php hybrid_attr( 'comment-author' ); ?>><span itemprop="name"><?php comment_author_link(); ?></span></span> <?php edit_comment_link( esc_html__( '(Edit)', 'reviewpro' ), '<span class="edit-link">', '</span>' ); ?></p>
		</article>
	<?php
			break;
		default :
		// Proceed with normal comments.
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>
		<article id="comment-<?php comment_ID(); ?>" class="comment-container">

			<div class="comment-avatar">
				<?php echo get_avatar( $comment, apply_filters( 'reviewpro_comment_avatar_size', 80 ) ); ?>
				<span class="name" <?php hybrid_attr( 'comment-author' ); ?>><span itemprop="name"><?php echo get_comment_author_link(); ?></span></span>
				<?php echo reviewpro_comment_author_badge(); ?>
			</div>

			<div class="comment-body">
				<div class="comment-wrapper">

					<div class="comment-head">
						<?php
							$edit_comment_link = '';
							if ( get_edit_comment_link() )
								$edit_comment_link = sprintf( esc_html__( '&middot; %1$sEdit%2$s', 'reviewpro' ), '<a href="' . get_edit_comment_link() . '" title="' . esc_attr__( 'Edit Comment', 'reviewpro' ) . '">', '</a>' );

							printf( '<span class="date"><a href="%1$s" ' . hybrid_get_attr( 'comment-permalink' ) . '><time datetime="%2$s" ' . hybrid_get_attr( 'comment-published' ) . '>%3$s</time></a> %4$s</span>',
								esc_url( get_comment_link( $comment->comment_ID ) ),
								get_comment_time( 'c' ),
								/* translators: 1: date, 2: time */
								sprintf( esc_html__( '%1$s at %2$s', 'reviewpro' ), get_comment_date(), get_comment_time() ),
								$edit_comment_link
							);
						?>
					</div><!-- comment-head -->

					<div class="comment-content comment-entry" <?php hybrid_attr( 'comment-content' ); ?>>
						<?php if ( '0' == $comment->comment_approved ) : ?>
							<p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'reviewpro' ); ?></p>
						<?php endif; ?>
						<?php comment_text(); ?>
						<span class="reply">
							<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( '<i class="fa fa-reply"></i> Reply', 'reviewpro' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
						</span><!-- .reply -->
					</div><!-- .comment-content -->

				</div>
			</div>

		</article><!-- #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}
endif;

if ( ! function_exists( 'reviewpro_comment_author_badge' ) ) :
/**
 * Custom badge for post author comment
 *
 * @since  1.0.0
 */
function reviewpro_comment_author_badge() {

	// Set up empty variable
	$output = '';

	// Get comment classes
	$classes = get_comment_class();

	if ( in_array( 'bypostauthor', $classes ) ) {
		$output = '<span class="author-badge">' . esc_html__( 'Author', 'reviewpro' ) . '</span>';
	}

	// Display the badge
	return apply_filters( 'reviewpro_comment_author_badge', $output );
}
endif;

if ( ! function_exists( 'reviewpro_get_first_image' ) ) :
/**
 * Return an HTML img tag for the first image in a post content. Used to draw
 * the content for posts of the “image” format.
 * http://css-tricks.com/snippets/wordpress/get-the-first-image-from-a-post/#comment-1582091 --> not working
 * http://www.wprecipes.com/how-to-get-the-first-image-from-the-post-and-display-it
 *
 * @return string An HTML img tag for the first image in a post content.
 */
function reviewpro_get_first_image( $size = 'full', $echo = true ) {

	// TO-DO: handle when $echo is false
	if ( has_post_thumbnail() && $echo ) {
		return reviewpro_featured_image( $size );
	}

	// Expose information about the current post.
	global $post;

	// We'll trap to see if this stays empty later in the function.
	$src = '';

	// Grab all img src's in the post content
	// $output = preg_match_all( '//i', $post->post_content, $matches ); // not working
	$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);

	// Grab the first img src returned by our regex.
	// if ( ! isset ( $matches[1][0] ) ) { return false; }
	// $src = $matches[1][0];

	// Grab the first <img> complete markup returned by our regex.
	if ( ! isset ( $matches[0][0] ) ) { return false; }
	$src = $matches[0][0];

	// Make sure there's still something worth outputting after sanitization.
	if ( empty( $src ) ) { return false; }

	// add wrapper
	$content = '<div class="entry-image clearfix">';
		$content .= '<a class="img-link" href="' . get_the_permalink() . '">';
			$content .= $src;
		$content .= '</a>';
	$content .= '</div>';

	// choose whether to echo the result or return it as variable
	if ( true == $echo )
		echo $content;
	else
		return $src;

}
endif;

if ( ! function_exists( 'reviewpro_footer_text' ) ) :
/**
 * Footer Text
 *
 * @since  1.0.0
 */
function reviewpro_footer_text() {

	// Get the customizer data
	$footer_text = reviewpro_mod( PREFIX . 'footer-text' );

	// Polylang integration
	if ( is_polylang_activated() ) {
		$footer_text = pllesc_html__( reviewpro_mod( PREFIX . 'footer-text' ) );
	}

	// Display the data
	echo '<p class="copyright">' . stripslashes( $footer_text ) . '</p>';

}
endif;
