<?php
/**
 * Social widget.
 *
 * @package    ReviewPro
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class ReviewPro_Social_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'widget_social_icons widget-reviewpro-social',
			'description' => __( 'Display your social media icons.', 'reviewpro' ),
			'customize_selective_refresh' => true
		);

		// Create the widget.
		parent::__construct(
			'reviewpro-social',                        // $this->id_base
			__( '&raquo; Social Icons', 'reviewpro' ), // $this->name
			$widget_options                            // $this->widget_options
		);

		$this->alt_option_name = 'widget_social_icons';
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Recent Posts widget instance.
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		// Set up default value
		$title     = ( ! empty( $instance['title'] ) ) ? $instance['title'] : '';
		$facebook  = ( ! empty( $instance['facebook'] ) ) ? esc_url( $instance['facebook'] ) : '';
		$twitter   = ( ! empty( $instance['twitter'] ) ) ? esc_url( $instance['twitter'] ) : '';
		$gplus     = ( ! empty( $instance['gplus'] ) ) ? esc_url( $instance['gplus'] ) : '';
		$pinterest = ( ! empty( $instance['pinterest'] ) ) ? esc_url( $instance['pinterest'] ) : '';
		$linkedin  = ( ! empty( $instance['linkedin'] ) ) ? esc_url( $instance['linkedin'] ) : '';
		$instagram = ( ! empty( $instance['instagram'] ) ) ? esc_url( $instance['instagram'] ) : '';
		$youtube   = ( ! empty( $instance['youtube'] ) ) ? esc_url( $instance['youtube'] ) : '';
		$vk        = ( ! empty( $instance['vk'] ) ) ? esc_url( $instance['vk'] ) : '';
		$rss       = ( ! empty( $instance['rss'] ) ) ? esc_url( $instance['rss'] ) : '';

		// Output the theme's $before_widget wrapper.
		echo $args['before_widget'];

		// If the title not empty, display it.
		if ( $instance['title'] ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $title, $instance, $this->id_base ) . $args['after_title'];
		}
		?>

			<?php if ( $facebook || $twitter || $gplus || $pinterest || $linkedin || $instagram || $vk || $rss ) : ?>
				<div class="widget-social-icons">
					<?php if ( $facebook ) { ?>
						<a class="facebook" href="<?php echo $facebook; ?>"><i class="fa fa-facebook"></i></a>
					<?php } ?>
					<?php if ( $twitter ) { ?>
						<a class="twitter" href="<?php echo $twitter; ?>"><i class="fa fa-twitter"></i></a>
					<?php } ?>
					<?php if ( $gplus ) { ?>
						<a class="gplus" href="<?php echo $gplus; ?>"><i class="fa fa-google-plus"></i></a>
					<?php } ?>
					<?php if ( $pinterest ) { ?>
						<a class="pinterest" href="<?php echo $pinterest; ?>"><i class="fa fa-pinterest"></i></a>
					<?php } ?>
					<?php if ( $linkedin ) { ?>
						<a class="linkedin" href="<?php echo $linkedin ?>"><i class="fa fa-linkedin"></i></a>
					<?php } ?>
					<?php if ( $instagram ) { ?>
						<a class="instagram" href="<?php echo $instagram; ?>"><i class="fa fa-instagram"></i></a>
					<?php } ?>
					<?php if ( $youtube ) { ?>
						<a class="youtube" href="<?php echo $youtube; ?>"><i class="fa fa-youtube"></i></a>
					<?php } ?>
					<?php if ( $rss ) { ?>
						<a class="rss" href="<?php echo $rss; ?>"><i class="fa fa-rss"></i></a>
					<?php } ?>
				</div>
			<?php endif; ?>

		<?php
		// Close the theme's widget wrapper.
		echo $args['after_widget'];

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {

		$instance               = $old_instance;
		$instance['title']      = sanitize_text_field( $new_instance['title'] );
		$instance['facebook']   = esc_url_raw( $new_instance['facebook'] );
		$instance['twitter']    = esc_url_raw( $new_instance['twitter'] );
		$instance['gplus']      = esc_url_raw( $new_instance['gplus'] );
		$instance['pinterest']  = esc_url_raw( $new_instance['pinterest'] );
		$instance['linkedin']   = esc_url_raw( $new_instance['linkedin'] );
		$instance['instagram']  = esc_url_raw( $new_instance['instagram'] );
		$instance['youtube']    = esc_url_raw( $new_instance['youtube'] );
		$instance['vk']         = esc_url_raw( $new_instance['vk'] );
		$instance['rss']        = esc_url_raw( $new_instance['rss'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : esc_html__( 'Follow Us', 'reviewpro' );
		$facebook  = isset( $instance['facebook'] ) ? esc_url( $instance['facebook'] ) : '';
		$twitter   = isset( $instance['twitter'] ) ? esc_url( $instance['twitter'] ) : '';
		$gplus     = isset( $instance['gplus'] ) ? esc_url( $instance['gplus'] ) : '';
		$pinterest = isset( $instance['pinterest'] ) ? esc_url( $instance['pinterest'] ) : '';
		$linkedin  = isset( $instance['linkedin'] ) ? esc_url( $instance['linkedin'] ) : '';
		$instagram = isset( $instance['instagram'] ) ? esc_url( $instance['instagram'] ) : '';
		$youtube   = isset( $instance['youtube'] ) ? esc_url( $instance['youtube'] ) : '';
		$vk        = isset( $instance['vk'] ) ? esc_url( $instance['vk'] ) : '';
		$rss       = isset( $instance['rss'] ) ? esc_url( $instance['rss'] ) : '';
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php esc_html_e( 'Title', 'reviewpro' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $title; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'facebook' ); ?>">
				<?php esc_html_e( 'Facebook', 'reviewpro' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'facebook' ); ?>" name="<?php echo $this->get_field_name( 'facebook' ); ?>" value="<?php echo $facebook; ?>" placeholder="<?php echo esc_attr( 'http://' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'twitter' ); ?>">
				<?php esc_html_e( 'Twitter', 'reviewpro' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'twitter' ); ?>" name="<?php echo $this->get_field_name( 'twitter' ); ?>" value="<?php echo $twitter; ?>" placeholder="<?php echo esc_attr( 'http://' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'gplus' ); ?>">
				<?php esc_html_e( 'Google Plus', 'reviewpro' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'gplus' ); ?>" name="<?php echo $this->get_field_name( 'gplus' ); ?>" value="<?php echo $gplus; ?>" placeholder="<?php echo esc_attr( 'http://' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'pinterest' ); ?>">
				<?php esc_html_e( 'Pinterest', 'reviewpro' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'pinterest' ); ?>" name="<?php echo $this->get_field_name( 'pinterest' ); ?>" value="<?php echo $pinterest; ?>" placeholder="<?php echo esc_attr( 'http://' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'linkedin' ); ?>">
				<?php esc_html_e( 'LinkedIn', 'reviewpro' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'linkedin' ); ?>" name="<?php echo $this->get_field_name( 'linkedin' ); ?>" value="<?php echo $linkedin; ?>" placeholder="<?php echo esc_attr( 'http://' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'instagram' ); ?>">
				<?php esc_html_e( 'Instagram', 'reviewpro' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'instagram' ); ?>" name="<?php echo $this->get_field_name( 'instagram' ); ?>" value="<?php echo $instagram; ?>" placeholder="<?php echo esc_attr( 'http://' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'youtube' ); ?>">
				<?php esc_html_e( 'Youtube', 'reviewpro' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'youtube' ); ?>" name="<?php echo $this->get_field_name( 'youtube' ); ?>" value="<?php echo $youtube; ?>" placeholder="<?php echo  esc_attr( 'http://' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'vk' ); ?>">
				<?php esc_html_e( 'VK', 'reviewpro' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'vk' ); ?>" name="<?php echo $this->get_field_name( 'vk' ); ?>" value="<?php echo $vk; ?>" placeholder="<?php echo  esc_attr( 'http://' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'rss' ); ?>">
				<?php esc_html_e( 'RSS Feed', 'reviewpro' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'rss' ); ?>" name="<?php echo $this->get_field_name( 'rss' ); ?>" value="<?php echo $rss; ?>" placeholder="<?php echo esc_attr( 'http://' ); ?>" />
		</p>

	<?php

	}

}
