<?php
/**
 * Tabbed widget.
 *
 * @package    ReviewPro
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class ReviewPro_Tabs_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'widget_tabs widget-reviewpro-tabs posts-thumbnail-widget',
			'description' => __( 'Display popular posts, recent posts, recent comments and tags in tabs.', 'reviewpro' ),
			'customize_selective_refresh' => true
		);

		// Create the widget.
		parent::__construct(
			'reviewpro-tabs',                  // $this->id_base
			__( '&raquo; Tabs', 'reviewpro' ), // $this->name
			$widget_options                    // $this->widget_options
		);

		$this->alt_option_name = 'widget_tabs';
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Recent Posts widget instance.
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		// Set up default value
		$popular  = ( ! empty( $instance['popular_num'] ) ) ? absint( $instance['popular_num'] ) : 5;
		$recent   = ( ! empty( $instance['recent_num'] ) ) ? absint( $instance['recent_num'] ) : 5;
		$comments = ( ! empty( $instance['comments_num'] ) ) ? absint( $instance['comments_num'] ) : 5;

		// Output the theme's $before_widget wrapper.
		echo $args['before_widget'];
		?>

		<ul class="tabs-nav">
			<li class="active"><a href="#tab1" title="<?php esc_attr_e( 'Popular', 'reviewpro' ); ?>"><?php esc_html_e( 'Popular', 'reviewpro' ); ?></a></li>
			<li><a href="#tab2" title="<?php esc_attr_e( 'Latest', 'reviewpro' ); ?>"><?php esc_html_e( 'Latest', 'reviewpro' ); ?></a></li>
			<li><a href="#tab3" title="<?php esc_attr_e( 'Comments', 'reviewpro' ); ?>"><?php esc_html_e( 'Comments', 'reviewpro' ); ?></a></li>
		</ul>

		<div class="tabs-container">
			<div class="tab-content" id="tab1">
				<?php $this->reviewpro_popular_posts( $popular ); ?>
			</div>

			<div class="tab-content" id="tab2">
				<?php $this->reviewpro_latest_posts( $recent ); ?>
			</div>

			<div class="tab-content" id="tab3">
				<?php $comments = get_comments( array( 'number' => $comments, 'status' => 'approve', 'post_status' => 'publish' ) ); ?>
				<?php if ( $comments ) : ?>
					<ul class="latest-comments">
						<?php foreach( $comments as $comment ) : ?>
							<li>
								<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
									<?php echo get_avatar( $comment->comment_author_email, '63' ); ?>
								</a>
								<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
									<strong><?php echo esc_attr( $comment->comment_author ); ?></strong>
									<span><?php echo wp_html_excerpt( $comment->comment_content, '80' ); ?></span>
								</a>
							</li>
						<?php endforeach; ?>
					</ul>
				<?php endif; ?>
			</div>
		</div>

		<?php
		// Close the theme's widget wrapper.
		echo $args['after_widget'];

	}

	/**
	 * Popular Posts by comment
	 *
	 * @since  1.0.0
	 */
	function reviewpro_popular_posts( $number = 5 ) {

		// Posts query arguments.
		$query = array(
			'posts_per_page' => $number,
			'orderby'        => 'comment_count',
			'post_type'      => 'post'
		);

		// The post query
		$popular = new WP_Query( $query );

		if ( $popular->have_posts() ) : ?>
			<ul>

				<?php while ( $popular->have_posts() ) : $popular->the_post(); ?>

					<li>
						<?php if ( has_post_thumbnail() ) : ?>
							<a class="thumbnail-link" href="<?php the_permalink(); ?>" rel="bookmark">
								<?php the_post_thumbnail( 'thumbnail', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
							</a>
						<?php endif; ?>
						<div class="post-detail">
							<a href="<?php the_permalink(); ?>" rel="bookmark"><?php the_title(); ?></a>
							<time class="entry-date" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>"><?php echo esc_html( get_the_date() ); ?></time>
						</div>
					</li>

				<?php endwhile; ?>

			</ul>

		<?php
		endif;

		// Reset the query.
		wp_reset_postdata();

	}

	/**
	 * Recent Posts
	 *
	 * @since 1.0.0
	 */
	function reviewpro_latest_posts( $number = 5 ) {

		// Posts query arguments.
		$args = array(
			'posts_per_page' => $number,
			'post_type'      => 'post',
		);

		// The post query
		$recent = new WP_Query( $args );

		if ( $recent->have_posts() ) : ?>
			<ul>

				<?php while ( $recent->have_posts() ) : $recent->the_post(); ?>

					<li>
						<?php if ( has_post_thumbnail() ) : ?>
							<a class="thumbnail-link" href="<?php the_permalink(); ?>" rel="bookmark">
								<?php the_post_thumbnail( 'thumbnail', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
							</a>
						<?php endif; ?>
						<div class="post-detail">
							<a href="<?php the_permalink(); ?>" rel="bookmark"><?php the_title(); ?></a>
							<time class="entry-date" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>"><?php echo esc_html( get_the_date() ); ?></time>
						</div>
					</li>

				<?php endwhile; ?>

			</ul>

		<?php
		endif;

		// Reset the query.
		wp_reset_postdata();

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {

		$instance                 = $old_instance;
		$instance['popular_num']  = absint( $new_instance['popular_num'] );
		$instance['recent_num']   = absint( $new_instance['recent_num'] );
		$instance['comments_num'] = absint( $new_instance['comments_num'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$popular  = isset( $instance['popular_num'] ) ? absint( $instance['popular_num'] ) : 5;
		$recent   = isset( $instance['recent_num'] ) ? absint( $instance['recent_num'] ) : 5;
		$comments = isset( $instance['comments_num'] ) ? absint( $instance['comments_num'] ) : 5;
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'popular_num' ); ?>">
				<?php _e( 'Number of Popular Posts', 'reviewpro' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'popular_num' ); ?>" name="<?php echo $this->get_field_name( 'popular_num' ); ?>" value="<?php echo $popular; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'recent_num' ); ?>">
				<?php _e( 'Number of Recent Posts', 'reviewpro' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'recent_num' ); ?>" name="<?php echo $this->get_field_name( 'recent_num' ); ?>" value="<?php echo $recent; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'comments_num' ); ?>">
				<?php _e( 'Number of Recent Comments', 'reviewpro' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'comments_num' ); ?>" name="<?php echo $this->get_field_name( 'comments_num' ); ?>" value="<?php echo $comments; ?>" />
		</p>

	<?php

	}

}
