<?php
/**
 * Most Views Posts with Thumbnail widget.
 *
 * @package    ReviewPro
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class ReviewPro_Views_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'widget-reviewpro-views posts-thumbnail-widget',
			'description' => esc_html__( 'Display the most views posts with thumbnails.', 'reviewpro' ),
			'customize_selective_refresh' => true
		);

		// Create the widget.
		parent::__construct(
			'reviewpro-views',                                                // $this->id_base
			esc_html__( '&raquo; Most Views Posts Thumbnails', 'reviewpro' ), // $this->name
			$widget_options                                                   // $this->widget_options
		);

	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

		// If the title not empty, display it.
		if ( $instance['title'] ) {
			echo $before_title . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $after_title;
		}

		// Posts query arguments.
		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => $instance['limit'],
			'orderby'        => 'meta_value_num',
			'meta_key'       => 'Views'
		);

		// The post query
		$views = new WP_Query( $args );

		// Set image size
		$size = 'thumbnail';
		if ( $instance['style'] !== 'default' ) {
			$size = 'post-thumbnail';
		}

		if ( $views->have_posts() ) : ?>
			<ul class="<?php echo $instance['style'] . '-style'; ?>">

				<?php while ( $views->have_posts() ) : $views->the_post(); ?>

					<li>
						<?php if ( $instance['style'] !== 'default' ) : ?>
							<?php reviewpro_first_category(); ?>
						<?php endif; ?>
						<?php if ( has_post_thumbnail() ) : ?>
							<a class="thumbnail-link" href="<?php the_permalink(); ?>" rel="bookmark">
								<?php the_post_thumbnail( $size, array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
								<span class="img-overlay"></span>
							</a>
						<?php endif; ?>
						<div class="post-detail">
							<a href="<?php the_permalink(); ?>" rel="bookmark"><?php the_title(); ?></a>
							<div class="entry-info">
								<?php if ( $instance['show_date'] ) : ?>
									<time class="entry-date" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>"><?php echo esc_html( get_the_date() ); ?></time>
								<?php endif; ?>
								<?php if ( $instance['show_view'] && function_exists( 'entry_views_get' ) ) : ?>
									<span class="entry-view">- <?php echo entry_views_get( array( 'after' => esc_html__( ' Views', 'reviewpro' ) ) ); ?></span>
								<?php endif; ?>
							</div>
						</div>
					</li>

				<?php endwhile; ?>

			</ul>
		<?php
		endif;

		// Reset the query.
		wp_reset_postdata();

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;
		$instance['title']     = strip_tags( $new_instance['title'] );
		$instance['limit']     = (int) $new_instance['limit'];
		$instance['show_date'] = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;
		$instance['show_view'] = isset( $new_instance['show_view'] ) ? (bool) $new_instance['show_view'] : false;
		$instance['style']     = isset( $new_instance['style'] ) ? esc_attr( $new_instance['style'] ) : 'default';

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'title'     => esc_html__( 'Most Views Posts', 'reviewpro' ),
			'limit'     => 5,
			'show_date' => false,
			'show_view' => false,
			'style'     => 'default'
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php esc_html_e( 'Title', 'reviewpro' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'limit' ); ?>">
				<?php esc_html_e( 'Number of posts to show', 'reviewpro' ); ?>
			</label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'limit' ); ?>" name="<?php echo $this->get_field_name( 'limit' ); ?>" type="number" step="1" min="0" value="<?php echo (int)( $instance['limit'] ); ?>" />
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['show_date'] ); ?> id="<?php echo $this->get_field_id( 'show_date' ); ?>" name="<?php echo $this->get_field_name( 'show_date' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'show_date' ); ?>">
				<?php esc_html_e( 'Display post date?', 'reviewpro' ); ?>
			</label>
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['show_view'] ); ?> id="<?php echo $this->get_field_id( 'show_view' ); ?>" name="<?php echo $this->get_field_name( 'show_view' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'show_view' ); ?>">
				<?php esc_html_e( 'Display post view?', 'reviewpro' ); ?>
			</label>
		</p>

		<p>
			<label for=""><?php esc_html_e( 'Style type', 'reviewpro' ); ?></label>
			<ul>
				<li>
					<input class="radio" type="radio" value="default" <?php checked( $instance['style'], 'default' ); ?> id="<?php echo $this->get_field_id( 'style' ); ?>-default" name="<?php echo $this->get_field_name( 'style' ); ?>" />
					<label for="<?php echo $this->get_field_id( 'style' ); ?>-default">
						<?php esc_html_e( 'Default', 'reviewpro' ); ?>
					</label>
				</li>
				<li>
					<input class="radio" type="radio" value="big-thumbnail" <?php checked( $instance['style'], 'big-thumbnail' ); ?> id="<?php echo $this->get_field_id( 'style' ); ?>-big-thumbnail" name="<?php echo $this->get_field_name( 'style' ); ?>" />
					<label for="<?php echo $this->get_field_id( 'style' ); ?>-big-thumbnail">
						<?php esc_html_e( 'Big Thumbnail', 'reviewpro' ); ?>
					</label>
				</li>
				<li>
					<input class="radio" type="radio" value="big-thumbnail-overlay" <?php checked( $instance['style'], 'big-thumbnail-overlay' ); ?> id="<?php echo $this->get_field_id( 'style' ); ?>-big-thumbnail-overlay" name="<?php echo $this->get_field_name( 'style' ); ?>" />
					<label for="<?php echo $this->get_field_id( 'style' ); ?>-big-thumbnail-overlay">
						<?php esc_html_e( 'Big Thumbnail Overlay', 'reviewpro' ); ?>
					</label>
				</li>
			</ul>
		</p>

	<?php

	}

}
